@@ -24,6 +24,7 @@ module CorePrelude
     , putStrLn
     , print
     , getArgs
+    , terror
     , Prelude.odd
     , Prelude.even
     , Prelude.uncurry
@@ -100,7 +101,10 @@ module CorePrelude
       -- ** Monoids
     , Monoid (..)
     , (<>)
-      -- ** Arrow
+      -- ** Folds and traversals
+    , Data.Foldable.Foldable
+    , Data.Traversable.Traversable
+      -- ** arrow
     , Control.Arrow.first
     , Control.Arrow.second
     , (Control.Arrow.***)
@@ -155,13 +159,9 @@ module CorePrelude
     , Control.Exception.Lifted.uninterruptibleMask_
     , module System.IO.Error
       -- ** Files
-    , F.FilePath
+    , Prelude.FilePath
     , (F.</>)
     , (F.<.>)
-    , F.hasExtension
-    , F.basename
-    , F.filename
-    , F.directory
       -- ** Strings
     , Prelude.String
       -- ** Hashing
@@ -186,7 +186,8 @@ import qualified Control.Exception
 import qualified Control.Exception.Lifted
 import qualified Data.Typeable
 
-import qualified Filesystem.Path.CurrentOS as F
+import qualified Data.Foldable
+import qualified Data.Traversable
 
 import Data.Word (Word8, Word32, Word64, Word)
 import Data.Int (Int32, Int64)
@@ -219,6 +220,7 @@ import Data.Sequence (Seq)
 import Data.HashMap.Strict (HashMap)
 import Data.HashSet (HashSet)
 import qualified ReadArgs
+import qualified System.FilePath as F
 
 import qualified System.Environment
 import qualified Data.Text
@@ -263,3 +265,9 @@ print = liftIO . Prelude.print
 
 readArgs :: (MonadIO m, ReadArgs.ArgumentTuple a) => m a
 readArgs = liftIO ReadArgs.readArgs
+
+-- | @error@ applied to @Text@
+--
+-- Since 0.4.1
+terror :: Text -> a
+terror = Prelude.error . Data.Text.unpack
